.. :changelog:

Changelog
---------

0.4.1 (2017-02-06)
++++++++++++++++++
* [UI] Add button to delete single or all messages


0.4.0 (2017-02-06)
++++++++++++++++++
* Add ``_contains`` filters
* Fix error with simple text format emails


0.3.1 (2016-09-02)
++++++++++++++++++
* Proper fix for ``message_from_string`` on Python 2

0.3.0 (2016-09-01)
++++++++++++++++++
* HTML multipart support (#2, #3)
* Fix multipart binary messages
